@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2011 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -46,8 +46,8 @@
 int
 doMain ( const int argc, const char *argv[] ) 
 {
-  const char* inputImagePath = NULL;
-  const char *outputPath = NULL;
+  std::string inputImagePath;
+  std::string outputPath;
   
   bool fitRigid = false;
 
@@ -75,7 +75,8 @@ doMain ( const int argc, const char *argv[] )
     cl.EndGroup();
 
     cl.AddParameter( &inputImagePath, "InputImage", "Input image path. This image determines the discrete sampling grid where the target transformation is estimated and fitted." )->SetProperties( cmtk::CommandLine::PROPS_IMAGE );
-    cl.AddParameterVector( &inputXformPaths, "XformList", "List of concatenated transformations. Insert '--inverse' to use the inverse of the transformation listed next." )->SetProperties( cmtk::CommandLine::PROPS_XFORM );
+    cl.AddParameterVector( &inputXformPaths, "XformList", "List of concatenated transformations. Insert '--inverse' to use the inverse of the transformation listed next. "
+			   "(If the first transformation in the sequence is inverted, then '--inverse' must be preceded by '--', i.e., use '-- --inverse xform.path')." )->SetProperties( cmtk::CommandLine::PROPS_XFORM );
  
     cl.Parse( argc, argv );
     }
@@ -90,9 +91,16 @@ doMain ( const int argc, const char *argv[] )
 
   cmtk::UniformVolume::SmartPtr imageGrid( cmtk::VolumeIO::ReadGridOriented( inputImagePath ) );
   
-  cmtk::FitAffineToXformList fit( *imageGrid, xformList );
-  cmtk::AffineXform::SmartPtr xform = fit.Fit( fitRigid );
-  cmtk::XformIO::Write( xform, outputPath );
+  try
+    {
+    cmtk::AffineXform::SmartPtr xform = cmtk::FitAffineToXformList( *imageGrid, xformList ).Fit( fitRigid );
+    cmtk::XformIO::Write( xform, outputPath );
+    }
+  catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+    {
+    cmtk::StdErr << "ERROR: singular matrix encountered in cmtk::FitAffineToXformList::Fit()\n";
+    return 1;
+    }
 
   return 0;
 }
