@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
@@ -59,6 +59,11 @@
 #define DCM_PatientsName DCM_PatientName
 #endif
 
+#ifndef DCM_Siemens_MosaicRefAcqTimes
+// Siemens tag for relative timing of all slices in a mosaic file
+#define DCM_Siemens_MosaicRefAcqTimes DcmTagKey(0x0019,0x1029)
+#endif
+
 #include <string>
 #include <map>
 #include <memory>
@@ -104,15 +109,26 @@ public:
   /// Dwell time for EPI
   double m_DwellTime;
 
+  /** Sign for phase encode direction.
+   * This is "pos" for "positive" phase encoding, "neg" for "negative", or "unknown"
+   */
+  std::string m_PhaseEncodeDirectionSign;
+
   /// B value for DWI.
-  Sint16 m_BValue;
+  double m_BValue;
 
   /// B vector for DWI.
   cmtk::FixedVector<3,double> m_BVector;
 
+  /// Flag whether this image has a valid B vector (false for average DWI images).
+  bool m_HasBVector;
+
   /// Raw data type string.
   std::string m_RawDataType;
 
+  /// Slice time(s) for this file.
+  std::vector<double> m_SliceTimes;
+
   /// Constructor.
   ImageFileDICOM( const std::string& filename );
 
@@ -173,6 +189,9 @@ private:
 
   /// Handle GE private tags.
   void DoVendorTagsGE();
+
+  /// Handle Philips private tags.
+  void DoVendorTagsPhilips();
 };
 
 //@}
