@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4405 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-06-01 11:16:42 -0700 (Fri, 01 Jun 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -107,7 +107,13 @@ VolumeIO::Read( const std::string& path )
     case FILEFORMAT_NRRD:
       volume = VolumeFromFile::ReadNRRD( translatedPath );
       break;
-    default: {}
+    case FILEFORMAT_NEXIST:
+      StdErr << "ERROR: could not find file " << path << "\n";
+      throw ExitException( 1 );      
+    default: 
+      StdErr << "ERROR: unidentified format of file " << path << "\n";
+      throw ExitException( 1 );
+      break;
     }
   
   if ( ! volume )
@@ -207,9 +213,9 @@ VolumeIO
 
 UniformVolume::SmartPtr
 VolumeIO
-::ReadOriented( const char *path, const char* orientation )
+::ReadOriented( const std::string& path, const char* orientation )
 {
-  UniformVolume::SmartPtr volume( VolumeIO::Read( path ) );
+  UniformVolume::SmartPtr volume( Self::Read( path ) );
 
   const std::string orientationOriginal = volume->GetMetaInfo( META_IMAGE_ORIENTATION );
   if ( orientationOriginal == "" )
@@ -350,8 +356,15 @@ VolumeIO::Write
     if ( volume.MetaKeyExists( cmtk::META_IMAGE_ORIENTATION_ORIGINAL ) &&
 	 (volume.GetMetaInfo( cmtk::META_IMAGE_ORIENTATION ) != volume.GetMetaInfo( cmtk::META_IMAGE_ORIENTATION_ORIGINAL ) ) )
       {
-      reorientedVolume = cmtk::UniformVolume::SmartConstPtr( volume.GetReoriented( volume.GetMetaInfo( cmtk::META_IMAGE_ORIENTATION_ORIGINAL ).c_str() ) );
-      actualVolume = reorientedVolume;
+      try
+	{
+	reorientedVolume = cmtk::UniformVolume::SmartConstPtr( volume.GetReoriented( volume.GetMetaInfo( cmtk::META_IMAGE_ORIENTATION_ORIGINAL ).c_str() ) );
+	actualVolume = reorientedVolume;
+	}
+      catch ( const AffineXform::MatrixType::SingularMatrixException& )
+	{
+	StdErr << "ERROR: singular matrix in cmtk::UniformVolume::GetReoriented(). Writing volume in current orientation.";
+	}
       }
     }
     
