@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4939 $
+//  $Revision: 5252 $
 //
-//  $LastChangedDate: 2013-10-04 10:49:00 -0700 (Fri, 04 Oct 2013) $
+//  $LastChangedDate: 2014-03-20 16:04:39 -0700 (Thu, 20 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -42,6 +42,7 @@
 #include <IO/cmtkClassStreamInput.h>
 #include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkClassStreamAffineXform.h>
+#include <IO/cmtkClassStreamPolynomialXform.h>
 #include <IO/cmtkTypedStreamStudylist.h>
 #include <IO/cmtkAffineXformITKIO.h>
 
@@ -95,7 +96,17 @@ XformIO::Read( const std::string& path )
       return Xform::SmartPtr( warpXform );
     
     stream.Open( realPath );
-
+    PolynomialXform polyXform;
+    try 
+      {
+      stream >> polyXform;
+      return Xform::SmartPtr( new PolynomialXform( polyXform ) );
+      }
+    catch ( const cmtk::Exception& )
+      {
+      }
+    
+    stream.Open( realPath );
     AffineXform affineXform;
     try 
       {
@@ -132,6 +143,14 @@ XformIO::Write
       {
       fileFormat = FILEFORMAT_NRRD;
       }
+    else if ( suffix == ".nii")
+      {
+      fileFormat = FILEFORMAT_NIFTI_SINGLEFILE;
+      }
+    else if ( suffix == ".img" )
+      {
+      fileFormat = FILEFORMAT_NIFTI_DETACHED;
+      }
     else
       {
       if ( (suffix == ".tfm") || (suffix == ".txt") )
@@ -152,6 +171,10 @@ XformIO::Write
       StdErr << "ERROR: XformIO::Write -- Nrrd support not configured.\n";
 #endif
       break;
+    case FILEFORMAT_NIFTI_DETACHED:
+    case FILEFORMAT_NIFTI_SINGLEFILE:
+      Self::WriteNIFTI( xform, absolutePath );
+      break;
     case FILEFORMAT_ITK_TFM:
     {
     const AffineXform* affineXform = dynamic_cast<const AffineXform*>( xform );
@@ -167,6 +190,10 @@ XformIO::Write
     if ( affineXform )
       stream << *affineXform;
     
+    const PolynomialXform* polyXform = dynamic_cast<const PolynomialXform*>( xform );
+    if ( polyXform )
+      stream << *polyXform;
+    
     const SplineWarpXform* splineWarpXform = dynamic_cast<const SplineWarpXform*>( xform );
     if ( splineWarpXform )
       stream << *splineWarpXform;
