@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4538 $
+//  $Revision: 4937 $
 //
-//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
+//  $LastChangedDate: 2013-10-04 10:37:43 -0700 (Fri, 04 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -34,8 +34,11 @@
 
 #include <Base/cmtkHistogramBase.h>
 #include <Base/cmtkTypedArrayNoiseEstimatorNaiveGaussian.h>
+
 #include <IO/cmtkVolumeIO.h>
+
 #include <System/cmtkProgress.h>
+#include <System/cmtkExitException.h>
 
 #include <algorithm>
 
@@ -54,6 +57,7 @@ VolumeInjectionReconstruction
 ::VolumeInjectionReconstruction( const UniformVolume* originalImage, const int interleaveFactor, const int interleaveAxis )
   : m_NumberOfPasses( interleaveFactor ),
     m_PassWeights( interleaveFactor ),
+    m_OriginalImageRange( 0, 0 ),
     m_OriginalImageHistogram(),
     m_CorrectedImageHistogram()
 {
@@ -87,6 +91,7 @@ VolumeInjectionReconstruction
 ::VolumeInjectionReconstruction( const UniformVolume* reconstructionGrid, std::vector<UniformVolume::SmartPtr>& images )
   : m_NumberOfPasses( images.size() ),
     m_PassWeights( images.size() ),
+    m_OriginalImageRange( 0, 0 ),
     m_OriginalImageHistogram( new Histogram<double>( Self::NumberOfHistogramBins ) ),
     m_CorrectedImageHistogram( new Histogram<double>( Self::NumberOfHistogramBins ) )
 {
@@ -392,7 +397,11 @@ VolumeInjectionReconstruction
 	    }
 	  else
 	    {
-	    this->m_TransformationsToPassImages[pass]->ApplyInverse( v, v );
+	    if ( ! this->m_TransformationsToPassImages[pass]->ApplyInverse( v, v ) )
+	      {
+	      StdErr << "ERROR: failed to apply inverse transformation in VolumeInjectionReconstruction::VolumeInjectionIsotropic\n";
+	      throw ExitException( 1 );
+	      }
 	    }
 	  
 	  int targetGridPosition[3];
@@ -519,7 +528,11 @@ VolumeInjectionReconstruction
     this->m_CorrectedImageLaplacians[idx-1] = l;
     lnorm += l*l;
     }
-  return lnorm / correctedImageNumPixels;
+
+  if ( correctedImageNumPixels )
+    lnorm /= correctedImageNumPixels;
+  
+  return lnorm;
 }
 
 void
