@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4510 $
+//  $Revision: 4882 $
 //
-//  $LastChangedDate: 2012-09-14 14:34:59 -0700 (Fri, 14 Sep 2012) $
+//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -117,10 +117,10 @@ protected:
     Self& operator-=( const Self& other );
 
     /** In-place single sample addition operator. */
-    void operator+=( const Types::DataItem* values );
+    void operator+=( const std::vector<Types::DataItem>& values );
 
     /** In-place single sample subtraction operator. */
-    void operator-=( const Types::DataItem* values );
+    void operator-=( const std::vector<Types::DataItem>& values );
   };
 
   /// Global data structure for metric computation.
