@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 5128 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2014-01-09 13:47:58 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -66,6 +66,7 @@ CompressedStream::Pipe::Pipe( const std::string& filename, const char* command )
     throw 0;
     } 
 #else
+  this->m_TempName[0] = 0;
   if ( snprintf( cmd, sizeof( cmd ), command, filename, tmpnam( this->m_TempName) ) >= sizeof( cmd ) )
     {
     StdErr << "WARNING: length of path exceeds system PATH_MAX in CompressedStream::OpenDecompressionPipe and will be truncated.\n";
@@ -91,13 +92,26 @@ CompressedStream::Pipe::Pipe( const std::string& filename, const char* command )
   this->m_BytesRead = 0;
 }
 
+CompressedStream::Pipe::~Pipe()
+{
+  this->Close();
+}
+
 void 
 CompressedStream::Pipe::Close()
 {
 #ifndef _MSC_VER
-  pclose( this->m_File );
+  if ( this->m_File )
+    {
+    pclose( this->m_File );
+    this->m_File = NULL;
+    }
 #else
-  remove( this->m_TempName );
+  if ( this->m_TempName[0] )
+    {
+    remove( this->m_TempName );
+    this->m_TempName[0] = 0;
+    }
 #endif // # ifndef _MSC_VER
 }
 
