@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2008-2012 SRI International
+//  Copyright 2008-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4156 $
+//  $Revision: 4876 $
 //
-//  $LastChangedDate: 2012-04-10 10:13:18 -0700 (Tue, 10 Apr 2012) $
+//  $LastChangedDate: 2013-09-24 13:09:58 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -291,14 +291,13 @@ TypedArrayNoiseEstimatorBrummer::EstimateNumBinsToUse
   UNUSED(data);
 
   double bestK = 0;
-  double curKMinimizer;
   double minKMinimizer = std::numeric_limits<double>::max(); 
  
   double maxK = histogram->GetNumberOfBins() / 2;
   
   for ( int curK = 1; curK < maxK; curK++ )
     {
-    curKMinimizer = SijbersBiasHat( histogram, sigmaHat, curK )+ SijbersVarHat( histogram, sigmaHat, curK );
+    const double curKMinimizer = SijbersBiasHat( histogram, sigmaHat, curK )+ SijbersVarHat( histogram, sigmaHat, curK );
 //std::cout << "minKMinimizer: " << minKMinimizer << std::endl;
 //std::cout << "curKMinimizer: " << curKMinimizer << std::endl;
     if ( curKMinimizer < minKMinimizer ) 
